#[non_exhaustive]pub struct Options<'a> {
pub input_wasm: &'a [u8],
pub output_dir: &'a Path,
pub main_out_path: &'a Path,
pub link_name: &'a Path,
pub main_module: &'a str,
pub verbose: bool,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.input_wasm: &'a [u8]The input wasm to split
output_dir: &'a PathWhere to put javascript wrappers, split wasm modules.
Default: Path::new("wasm_split")
main_out_path: &'a PathWhere to put the main module that has to be post-processed by wasm-bindgen.
Usually a path in output_dir.
Default: Path::new("wasm_split/main.wasm")
link_name: &'a PathPath of the created link file, relative to the output dir.
The wasm will use this path to import the loader functions for the split chunks.
This must match the link_name used in the macro.
Default: Path::new("./__wasm_split.js")
main_module: &'a strFrom where will initSync be imported from?
Default: "./main.js"
verbose: boolVerbosely output additional information about processing.
Default: false
Implementations